@@ -448,6 +448,7 @@ gst_v4l2src_fixed_caps_compare (GstCaps * caps_a, GstCaps * caps_b,
   gint a_fps_n = G_MAXINT, a_fps_d = 1;
   gint b_fps_n = G_MAXINT, b_fps_d = 1;
   gint a_distance, b_distance;
+  gint ret = 0;
 
   a = gst_caps_get_structure (caps_a, 0);
   b = gst_caps_get_structure (caps_b, 0);
@@ -468,7 +469,11 @@ gst_v4l2src_fixed_caps_compare (GstCaps * caps_a, GstCaps * caps_b,
   a_distance = ABS (aw * ah - pref->width * pref->height);
   b_distance = ABS (bw * bh - pref->width * pref->height);
 
-  gint ret = a_distance - b_distance;
+  /* If the distance are equivalent, maintain the order */
+  if (a_distance == b_distance)
+    ret = 1;
+  else
+    ret = a_distance - b_distance;
 
   GST_TRACE ("Placing %" GST_PTR_FORMAT " %s %" GST_PTR_FORMAT,
       caps_a, ret > 0 ? "after" : "before", caps_b);
@@ -682,7 +687,8 @@ gst_v4l2src_query_preferred_size (GstV4l2Src * v4l2src,
   GST_INFO_OBJECT (v4l2src, "Detect input %u as `%s`", in.index, in.name);
 
   /* Notify signal status using WARNING/INFO messages */
-  if (in.status & (V4L2_IN_ST_NO_POWER | V4L2_IN_ST_NO_SIGNAL)) {
+  if (in.status & (V4L2_IN_ST_NO_POWER | V4L2_IN_ST_NO_SIGNAL |
+          V4L2_IN_ST_NO_SYNC)) {
     if (!v4l2src->no_signal)
       /* note: taken from decklinksrc element */
       GST_ELEMENT_WARNING (v4l2src, RESOURCE, READ, ("Signal lost"),
